@@ -48,6 +48,18 @@ ui = fluidPage(
                   choices = list('Browser' = 'Browser', 'R' = 'R'),
                   selected = 'Browser', inline = TRUE, width = NULL
                 ),
+                sliderInput(
+                  'pitch',
+                  'Playback pitch, Hz',
+                  value = 150,
+                  min = 20,
+                  max = 500,
+                  step = 5
+                ),
+                checkboxInput(
+                  'adaptivePitch',
+                  'Adapt playback pitch by imflied VTL',
+                  value = TRUE),
                 sliderInput(
                   'samplingRate_mult',
                   'Playback speed, 2 ^',
